@@ -18,7 +18,7 @@ from pyinels.api import Api
 from pyinels.device.pyLight import pyLight
 
 from unittest.mock import patch
-from unittest import TestCase
+from unittest import async_case
 
 MIN_RANGE = RANGE_BRIGHTNESS[0]
 MAX_RANGE = RANGE_BRIGHTNESS[1]
@@ -34,7 +34,7 @@ LIGHT_RETURN_DIMMABLE_ON = {LIGHT_ID: MAX_RANGE}
 LIGHT_RETURN_DIMMABLE_50 = {LIGHT_ID: 50}
 
 
-class PyLightTest(TestCase):
+class PyLightTest(async_case.IsolatedAsyncioTestCase):
     """Class to test iNels light library."""
 
     def setUp(self):
@@ -53,10 +53,13 @@ class PyLightTest(TestCase):
             p.start()
 
         self.api = Api(TEST_HOST, TEST_PORT, TEST_VERSION)
-        lights = [device for device in self.api.getRoomDevices(
+
+    async def asyncSetUp(self):
+        """Setup all neccessary async stuff."""
+        lights = [device for device in await self.api.getRoomDevices(
             'garage') if device.type == ATTR_LIGHT]
 
-        self.light = pyLight(lights[0])
+        self.light = await pyLight(lights[0])
 
     def tearDown(self):
         """Destroy all instances and mocks."""
@@ -75,11 +78,11 @@ class PyLightTest(TestCase):
         self.assertIsNotNone(lg.unique_id)
         self.assertEqual(lg.unique_id, LIGHT_ID)
 
-    def test_state(self):
+    async def test_state(self):
         """Test the state of the pyLight."""
         lg = self.light
 
-        lg.update()
+        await lg.update()
         # the light at the beggining should be turned off
         self.assertFalse(lg.state)
 
@@ -90,43 +93,43 @@ class PyLightTest(TestCase):
         self.assertIsNotNone(lg.unique_id)
         self.assertIsNotNone(lg.name)
 
-    def test_turn_on(self):
+    async def test_turn_on(self):
         """Test turn on the light."""
         lg = self.light
 
-        lg.update()
+        await lg.update()
         self.assertFalse(lg.state)
 
         with patch.object(self.api, TEST_API_READ_DATA,
                           return_value=LIGHT_RETURN_ON):
-            lg.turn_on()
+            await lg.turn_on()
 
-            lg.update()
+            await lg.update()
             self.assertTrue(lg.state)
 
-        lg.turn_off()
+        await lg.turn_off()
 
-        lg.update()
+        await lg.update()
         self.assertFalse(lg.state)
 
-    def test_turn_off(self):
+    async def test_turn_off(self):
         """Test turn off the light."""
         lg = self.light
 
         with patch.object(self.api, TEST_API_READ_DATA,
                           return_value=LIGHT_RETURN_ON):
-            lg.turn_on()
+            await lg.turn_on()
 
-            lg.update()
+            await lg.update()
             self.assertTrue(lg.state)
 
-        lg.turn_off()
+        await lg.turn_off()
 
-        lg.update()
+        await lg.update()
         self.assertFalse(lg.state)
 
 
-class PyLightDimmableTest(TestCase):
+class PyLightDimmableTest(async_case.IsolatedAsyncioTestCase):
     """Class to test iNels light library."""
 
     def setUp(self):
@@ -145,10 +148,13 @@ class PyLightDimmableTest(TestCase):
             p.start()
 
         self.api = Api(TEST_HOST, TEST_PORT, TEST_VERSION)
-        lights = [device for device in self.api.getRoomDevices(
+
+    async def asyncSetUp(self):
+        """Setup all neccessary async stuff."""
+        lights = [device for device in await self.api.getRoomDevices(
             'garage') if device.type == ATTR_LIGHT]
 
-        self.light = pyLight(lights[0])
+        self.light = await pyLight(lights[0])
 
     def tearDown(self):
         """Destroy all instances and mocks."""
@@ -157,41 +163,41 @@ class PyLightDimmableTest(TestCase):
         patch.stopall()
         self.patches = None
 
-    def test_turn_on_with_brightness_option(self):
+    async def test_turn_on_with_brightness_option(self):
         """Test the light to turn on when the brightness exists."""
 
         lg = self.light
 
-        lg.update()
+        await lg.update()
         self.assertFalse(lg.state)
         self.assertTrue(lg.has_brightness)
 
         with patch.object(self.api, TEST_API_READ_DATA,
                           return_value=LIGHT_RETURN_DIMMABLE_ON):
-            lg.turn_on()
+            await lg.turn_on()
 
-            lg.update()
+            await lg.update()
             self.assertTrue(lg.state)
 
-    def test_set_brightness_to_50_percent(self):
+    async def test_set_brightness_to_50_percent(self):
         """Test the brightnes to some value."""
 
         lg = self.light
 
-        lg.update()
+        await lg.update()
         self.assertFalse(lg.state)
         self.assertTrue(lg.has_brightness)
 
         with patch.object(self.api, TEST_API_READ_DATA,
                           return_value=LIGHT_RETURN_DIMMABLE_50):
 
-            lg.set_brightness(50)
+            await lg.set_brightness(50)
 
             self.assertEqual(lg.brightness(), 50)
             self.assertTrue(lg.state)
 
     @patch(f'{TEST_API_CLASS_NAMESPACE}.{TEST_API_READ_DATA}')
-    def test_turn_off_with_brightness_option(self, mock_room_devices):
+    async def test_turn_off_with_brightness_option(self, mock_room_devices):
         """Test the light to turn off when the brightness exsists."""
         mock_room_devices.return_value = LIGHT_RETURN_DIMMABLE_ON
 
@@ -199,13 +205,13 @@ class PyLightDimmableTest(TestCase):
 
         self.assertTrue(lg.has_brightness)
 
-        lg.update()
+        await lg.update()
         self.assertTrue(lg.state)
 
         with patch.object(self.api, TEST_API_READ_DATA,
                           return_value=LIGHT_RETURN_DIMMABLE_OFF):
-            lg.turn_off()
+            await lg.turn_off()
             self.assertTrue(lg.has_brightness)
 
-            lg.update()
+            await lg.update()
             self.assertFalse(lg.state)
